@@ -5,12 +5,12 @@
 
 jomo2datlist <- function( jomo.dataframe , variable="Imputation" ){
     dat <- jomo.dataframe
-    M1 <- max( unique( dat$Imputation ) )
-    datlist <- as.list( 1:M1 )
-    ind <- which( colnames(dat) == variable )
+    M1 <- base::max( base::unique( dat$Imputation ) )
+    datlist <- base::as.list( 1:M1 )
+    ind <- base::which( base::colnames(dat) == variable )
     for ( mm in 1:M1){
         datlist[[mm]] <- dat[ dat$Imputation == mm , - ind ]
                     }
-    return(datlist)
-            }
+    base::return(datlist)
+}
 
